@@ -3,7 +3,7 @@ import os.path
 import yaml
 from dominator.utils import aslist, resource_string
 from dominator.entities import (Image, SourceImage, Container, DataVolume, ConfigVolume, LogVolume, TemplateFile,
-                                YamlFile, TextFile, LogFile, LocalShip, Shipment, Task)
+                                YamlFile, TextFile, LogFile, LocalShip, Shipment, Task, Door)
 from obedient import zookeeper
 
 
@@ -196,7 +196,7 @@ def getbuilder(
             config = make_config(ship)
             add_service(config, 'splitter')
             add_rules(config)
-            return container(ship, 'splitter', config, volumes={'rules': rules}, backdoor=11002, ports={})
+            return container(ship, 'splitter', config, volumes={'rules': rules}, backdoor=11002, doors={})
 
         @staticmethod
         def worker(ship):
@@ -204,19 +204,19 @@ def getbuilder(
             add_service(config, 'worker')
             add_rules(config)
             add_output(config, 'powny@'+ship.fqdn)
-            return container(ship, 'worker', config, volumes={'rules': rules}, backdoor=11001, ports={})
+            return container(ship, 'worker', config, volumes={'rules': rules}, backdoor=11001, doors={})
 
         @staticmethod
         def restapi(ship, name='api', port=restapi_port):
             config = make_config(ship)
             return container(ship, name, config, files={'uwsgi.ini': uwsgi_ini_file},
-                              backdoor=None, ports={'http': port}, image=apiimage, logs=restapilogs)
+                              backdoor=None, doors={'http': port}, image=apiimage, logs=restapilogs)
 
         @staticmethod
         def collector(ship):
             config = make_config(ship)
             add_service(config, 'collector')
-            return container(ship, 'collector', config, backdoor=11003, ports={})
+            return container(ship, 'collector', config, backdoor=11003, doors={})
 
         @staticmethod
         def gitapi(ship):
@@ -231,8 +231,7 @@ def getbuilder(
                     'keys': keys,
                     'logs': gitapilogs,
                 },
-                ports=gitimage.ports,
-                extports={'ssh': gitapi_port},
+                doors={'ssh': Door(schema='ssh', port=gitimage.ports['ssh'], externalport=gitapi_port)},
                 env={
                     'rules_git_path': rulesgit.dest,
                     'rules_path': rules.dest,
